# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Resource types

* [`iib_broker`](#iib_broker): This resource allows you to manage broker in an IBM IIB realm.  Here is an example on how you should use this:      iib_broker { 'IIB107/IB10
* [`iib_credential`](#iib_credential): This resource allows you to manage dbparams (e.g. credentials) in IBM IIB realm.  Here is an example on how you should use this:      iib_cre
* [`iib_deployment`](#iib_deployment): This resource allows you to manage process of deployment of IBM IIB.  Here is an example on how you should use this:      iib_deployment { 'I
* [`iib_instance`](#iib_instance): This is custom resource which allows you to manage server and broker under specified account in an IBM IIB realm.  Here is an example on how 
* [`iib_property`](#iib_property): This resource allows you to manage brokers and servers in an IBM IIB realm.  This type can be used to construct `mqsichangebroker` or `mqsich
* [`iib_security_profile`](#iib_security_profile): This resource allows you to manage Security Profile of node (broker) in an IBM IIB realm.  Here is an example on how you should use this:    
* [`iib_server`](#iib_server): This resource allows you to manage server in an IBM IIB realm.  Here is an example on how you should use this:      iib_server { 'IIB107/IB10

### Tasks

* [`broker`](#broker): Allows get the status, create or remove an IIB Broker
* [`deployment`](#deployment): Allows get the status, create or remove an IIB deployment
* [`server`](#server): Allows get the status, create or remove an IIB Server (executiongroup)

## Resource types

### <a name="iib_broker"></a>`iib_broker`

This resource allows you to manage broker in an IBM IIB realm.

Here is an example on how you should use this:

    iib_broker { 'IIB107/IB10NODE1':
      ensure => 'present',
      status => 'running',
    }

In this example you are ensuring that broker is running. If the server is
stopped the resource starts broker, if broker is absent then new is created.

Valid managable global node component names:
- userLilPath
- configurationChangeTimeout
- internalConfigurationTimeout
- httpListenerPort
- statisticsMajorInterval
- ldapPrincipal
- ldapCredentials
- ICU converter path
- userExitPath
- activeUserExits
- function level
- security_status
- cachePolicy
- cachePortRange
- integrationRegistryHostname

#### Properties

The following properties are available in the `iib_broker` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `iib_broker` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_broker` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="iib_credential"></a>`iib_credential`

This resource allows you to manage dbparams (e.g. credentials) in IBM IIB realm.

Here is an example on how you should use this:

    iib_credential { 'IIB107/ldap::myad.example.com':
      ensure   => 'present',
      username => 'myusername',
      password => 'extremlysecret',
    }

#### Properties

The following properties are available in the `iib_credential` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `iib_credential` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_credential` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="iib_deployment"></a>`iib_deployment`

This resource allows you to manage process of deployment of IBM IIB.

Here is an example on how you should use this:

    iib_deployment { 'IIB107/IB10NODE1/server_2/Hello':
      ensure => 'present',
      source => '/tmp/Helloproject.TestMode.bar',
    }

In this example you are ensuring that deployment is done from provided source.

#### Properties

The following properties are available in the `iib_deployment` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `iib_deployment` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_deployment` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="iib_instance"></a>`iib_instance`

This is custom resource which allows you to manage server and broker under
specified account in an IBM IIB realm.

Here is an example on how you should use this:

    iib_instance { 'IIB107NewInstance':
      ensure         => 'present',
      home_directory => '/opt/ibm/mqsi/iib-10.0.0.7',
      os_user        => 'iibadmin',
    }

In this example you are ensuring that instance is present. If the instance is
absent the resource creates new istance with specifed user and directory.

#### Properties

The following properties are available in the `iib_instance` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `iib_instance` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_instance` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="iib_property"></a>`iib_property`

This resource allows you to manage brokers and servers in an IBM IIB realm.

This type can be used to construct `mqsichangebroker` or `mqsichangeproperties`
commands for you setup. This type is a fallback for when the property is not
(yet) support on `iib_broker` or `iib_server`. Use this type with care.

Here is an example on how to write manifest for global node component value
changing:

    iib_property {'set_node_cache_policy':
      scope     => 'iib8/NODE1',
      component => 'cachePolicy',
      restart   => true,
      set_value => 'none'
    }


Valid global node component names:
- userLilPath
- configurationChangeTimeout
- internalConfigurationTimeout
- httpListenerPort
- statisticsMajorInterval
- ldapPrincipal
- ldapCredentials
- ICU converter path
- userExitPath
- activeUserExits
- function level
- security_status
- cachePolicy
- cachePortRange
- integrationRegistryHostname

Here is an example on how to write manifest for node component that takes
objectName:

    iib_property {'set_node_cache_policy':
      scope            => 'iib8/NODE1',
      component        => 'webadmins',
      object_name      => 'HTTPConnector',
      object_property  => 'compression',
      restart          => false,
      set_value        => 'on'
    }

Make sure that selected node is running before applying manifest.

Valid node component names that take objectName:
- httplistener
- securitycache
- cachemanager
- webadmin
- crlFile

Here is an example on how to write manifest for server property
changing:

    iib_property {'set_server_accept_count_to_200':
      scope       => 'iib8/NODE1/server_1',
      component   => 'HTTPConnector',
      object_name => 'acceptCount',
      restart     => false,
      set_value   => '200'
    }

#### Parameters

The following parameters are available in the `iib_property` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_property` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="iib_security_profile"></a>`iib_security_profile`

This resource allows you to manage Security Profile of node (broker) in an IBM
IIB realm.

Here is an example on how you should use this:

    iib_security_profile { '10.0.0.6/NODE/SECURITY_NAME':
      ensure                       => 'present',
      authentication               => 'NONE',
      authorization                => 'NONE',
      id_to_propagate_to_transport => 'Message ID',
      keystore                     => 'Reserved for future use',
      mapping                      => 'NONE',
      password_value               => 'PLAIN',
      propagation                  => true,
      reject_blank_password        => false,
      trust_store                  => 'Reserved for future use',
    }

#### Properties

The following properties are available in the `iib_security_profile` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `iib_security_profile` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_security_profile` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="iib_server"></a>`iib_server`

This resource allows you to manage server in an IBM IIB realm.

Here is an example on how you should use this:

    iib_server { 'IIB107/IB10NODE1/server_1':
      ensure => 'present',
      status => 'running',
    }

In this example you are ensuring that server is running. If the server is
stopped the resource starts server, if absent the new server is created.

#### Properties

The following properties are available in the `iib_server` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `iib_server` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_server` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

## Tasks

### <a name="broker"></a>`broker`

Allows get the status, create or remove an IIB Broker

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Optional[Enum['list', 'status','create','remove']]`

The action you want to execute

##### `broker_name`

Data type: `Optional[String[1]]`

The name of the IIB Broker to use.

##### `properties`

Data type: `Optional[Hash]`

The properties to use when create a IIB Broker

### <a name="deployment"></a>`deployment`

Allows get the status, create or remove an IIB deployment

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Optional[Enum['list', 'status','create','remove']]`

The action you want to execute

##### `depoyment_name`

Data type: `Optional[String[1]]`

The name of the IIB deployment to use.

##### `properties`

Data type: `Optional[Hash]`

The properties to use when create a IIB deployment

### <a name="server"></a>`server`

Allows get the status, create or remove an IIB Server (executiongroup)

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Optional[Enum['list', 'status','create','remove']]`

The action you want to execute

##### `server_name`

Data type: `Optional[String[1]]`

The name of the IIB Server to use.

##### `properties`

Data type: `Optional[Hash]`

The properties to use when create a IIB Server

