#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
require 'puppet_x/enterprisemodules/iib/command'
require 'puppet_x/enterprisemodules/iib/settings'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/node_component'
require 'puppet_x/enterprisemodules/iib/broker_global_property'
require 'puppet_x/enterprisemodules/iib/ace_check'
require 'puppet_x/enterprisemodules/iib/ace_helpers'

class Puppet_X::EnterpriseModules::Iib::BrokerGlobalProperty < Puppet::Property
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::AceCheck
  include Puppet_X::EnterpriseModules::Iib::AceHelpers
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings
  extend  Puppet_X::EnterpriseModules::Iib::NodeComponent

  def self.maps_to(object_name)
    self.object_name(object_name)
  end

  def self.object_name(object_name = nil)
    @object_name = object_name || @object_name
  end

  def self.attribute_value(output)
    return output[object_name] if output.kind_of?(Hash) # if yaml property
    output.scan(/#{Regexp.escape(component_regexp_string(object_name))}\s=\s\'([^\']*)\'/)[0][0]
  end

  def self.translate_to_resource(raw_resource, resource)
    raw_resource.merge(resource)

    if ace_used?(raw_resource[:instance])
      return yaml_value(raw_resource , 'iib_broker')
    else
      value = attribute_value(raw_resource[:global_output])
      return nil if value.nil?

      value.empty? ? nil : value
    end
  end

  def new_attribute_value(resource, object_name, value)
    mqsichangebroker("#{resource[:broker]} " \
                     "#{self.class.component_modifier(object_name)} #{value}",
                     { :instance => resource[:instance] })
  end

  on_create do
    "#{self.class.component_modifier(self.class.object_name)} #{value}"
  end

  on_modify do
    if resource[:auto_restart].to_s == 'false' && provider.status == 'running'
      Puppet.warning "#{path}: skipping change because broker is running and auto_restart is false."
      return nil
    end
    if resource[:auto_restart].to_s == 'true' && provider.status == 'running'
      Puppet.debug "Stopping broker #{resource.broker} before applying global property."
      mqsistop(resource.broker, { :instance => resource.instance })
      # TODO Find a better way to do this. This is right now
      # very much based o the implementation
      provider.property_hash[:status] = 'stopped'
    end

    if ace_used?(resource[:instance])
      self.class.write_to_yaml(resource, value, 'iib_broker')
    else
      new_attribute_value(resource, self.class.object_name, value)
    end
  end
end
