#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
require 'puppet_x/enterprisemodules/iib/ace_check'

module Puppet_X
  module EnterpriseModules
    module Iib
      module BrokerInfo
        include Puppet_X::EnterpriseModules::Iib::AceCheck

        def broker_property(broker, component, iib_instance, object_name)
          mqsireportproperties("#{broker} -b #{component} -o #{object_name} -a",
                               { :instance => iib_instance })
        end

        def broker_registry(broker, iib_instance)
          mqsireportproperties("#{broker} -o BrokerRegistry -a",
                               { :instance => iib_instance })
        end

        def component_objects
          {
            'HTTPListener'   => 'httplistener',
            'HTTPConnector'  => 'httplistener',
            'HTTPSConnector' => 'httplistener',
            'SecurityCache'  => 'securitycache',
            'scmp'           => 'servicefederation'
          }.freeze
        end

        def component_name(object_name)
          component_objects[object_name]
        end

        def shared_properties(element, iib_instance)
          object_properties_hash = {}

          return yaml_properties(element) if ace_used?(iib_instance)

          component_objects.map do |object_name, component|
            object_properties_hash[object_name] = broker_property(element, component, iib_instance, object_name)
          end

          object_properties_hash['BrokerRegistry'] = broker_registry(element, iib_instance)

          object_properties_hash
        end

        def global_properties_output(broker, iib_instance)
          return yaml_properties(broker) if ace_used?(iib_instance)

          mqsireportbroker(broker, { :instance => iib_instance })
        end

        def yaml_properties(broker)
          YAML.load_file("/var/mqsi/components/#{broker}/node.conf.yaml")
        end
      end
    end
  end
end
