#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
require 'puppet_x/enterprisemodules/iib/ace_check'
require 'puppet_x/enterprisemodules/iib/ace_helpers'
require 'puppet_x/enterprisemodules/iib/broker_info'
require 'puppet_x/enterprisemodules/iib/command'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/property_mapper'
require 'puppet_x/enterprisemodules/iib/settings'

class Puppet_X::EnterpriseModules::Iib::BrokerSharedProperty < Puppet::Property
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::AceCheck
  include Puppet_X::EnterpriseModules::Iib::AceHelpers
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings
  extend  Puppet_X::EnterpriseModules::Iib::BrokerInfo
  extend  Puppet_X::EnterpriseModules::Iib::PropertyMapper

  def self.translate_to_resource(raw_resource, resource)
    return nil unless resource[:status] =='running'

    raw_resource.merge(resource)

    if ace_used?(raw_resource[:instance])
      return yaml_value(raw_resource, 'iib_broker')
    else
      value = attrbute_value(raw_resource[:shared_properties_output], object_name, attribute_name)
    end
    return nil if value.nil?

    value.empty? ? nil : value
  end

  def self.assign_value(node, object_name, attribute_name, value, instance)
    mqsichangeproperties("#{node} -b #{component_name(object_name)} -o " \
                         "#{object_name} -n #{attribute_name} -v #{value}",
                         { :instance => instance })
  end

  def new_attribute_value(resource, object_name, attribute_name, value)
    self.class.assign_value(resource[:broker], object_name, attribute_name, value, resource[:instance])
  end

  after_create do
    if ace_used?(resource[:instance])
      self.class.write_to_yaml(resource, value, 'iib_broker')
    else
      new_attribute_value(resource, self.class.object_name, self.class.attribute_name, value)
    end
  end

  on_modify do
    if ace_used?(resource[:instance])
      self.class.write_to_yaml(resource, value, 'iib_broker')
    else
      new_attribute_value(resource, self.class.object_name, self.class.attribute_name, value)
    end
  end
end
