#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
require 'puppet_x/enterprisemodules/iib/access'

module Puppet_X
  module EnterpriseModules
    module Iib
      #
      # This is module responsible for executing single command
      class Command
        include Puppet_X::EnterpriseModules::Iib::Access
        DEFAULT_TIMEOUT = 300 # 5 minutes

        VALID_OPTIONS = [:instance, :timeout].freeze

        attr_reader(*VALID_OPTIONS)

        def initialize(command, options, valid_options = VALID_OPTIONS)
          @valid_options   = valid_options
          check_options(options)
          @command         = command
          @timeout         = options.fetch(:timeout)  { DEFAULT_TIMEOUT }
          @instance        = options.fetch(:instance) { raise 'No instance provided' }
          raise "#{@instance} not registered as an instance." if configuration[@instance].nil?
          @configuration   = configuration[@instance]
          @os_user         = @configuration.fetch('os_user') { raise 'No os_user provided' }
          @home_directory  = @configuration.fetch('home_directory') { raise 'No home_directory provided' }
        end

        def command_string(arguments = '')
          "su - #{@os_user} -c \". #{@home_directory}/server/bin/mqsiprofile; #{@command} #{arguments}\""
        end

        def execute(arguments)
          options = { :failonfail => true, :combine => true }
          value = ''
          within_time(@timeout) do
            Puppet.debug "Executing #{@command} command: #{arguments} "
            value = Puppet::Util::Execution.execute(command_string(arguments), options)
          end
          value
        end

        private

        def within_time(timeout)
          Puppet.debug "Using timeout #{timeout}"
          if timeout.zero?
            yield
          else
            Timeout.timeout(timeout) do
              yield
            end
          end
        end

        def check_options(options)
          options.each_key do |key|
            unless @valid_options.include?(key)
              raise ArgumentError, "option #{key} invalid for #{@command}. Only #{@valid_options.join(', ')} are supported"
            end
          end
        end
      end
    end
  end
end
