#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
class Puppet_X::EnterpriseModules::Iib::SecurityProfileBooleanProperty < Puppet_X::EnterpriseModules::Iib::SecurityProfileProperty
  def self.translate_to_resource(raw_resource, resource)
    raw_resource.merge(resource)

    if ace_used?(raw_resource[:instance])
      return yaml_value(raw_resource, 'iib_security_profile')
    end

    fetched_value = raw_resource[:output][attribute_name]
    return :false if ['FALSE', 'false', :false].include?(fetched_value) # rubocop:disable Lint/BooleanSymbol
    return :true if ['TRUE', 'true', :true].include?(fetched_value) # rubocop:disable Lint/BooleanSymbol
    return nil if ['', nil, :no, 'no', :undef].include?(fetched_value)

    raise ArgumentError, "Value '#{fetched_value}':#{fetched_value.class} cannot be determined as a boolean value"
  end

  def self.assign_value(node, security_profile, attribute_name, original_value, instance)
    value = 'TRUE' if [true, 'true', :true, :yes, 'yes', 'TRUE'].include?(original_value)
    value = 'FALSE' if [false, 'false', :false, :no, 'no', :undef, 'FALSE'].include?(original_value)
    mqsichangeproperties("#{node} -c SecurityProfiles -o " \
                         "#{security_profile} -n #{attribute_name} -v #{quoted_value(value)}",
                         { :instance => instance })
  end

  def self.quoted_value(value)
    return value unless @quote_values
    # Values with comma's need some strange escaping
    if value.include?(',')
      "\\\\\\\"#{value}\\\\\\\""
    else
      "'#{value}'"
    end
  end
end
