#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
module Puppet_X
  module EnterpriseModules
    module Iib
      module SecurityProfileInfo
        def object_names_list
          [
            'authentication',
            'authenticationConfig',
            'authorization',
            'authorizationConfig',
            'idToPropagateToTransport',
            'keyStore',
            'mapping',
            'mappingConfig',
            'passwordValue',
            'propagation',
            'rejectBlankpassword',
            'transportPropagationConfig',
            'trustStore'
          ].freeze
        end

        def properties_output(broker, element, iib_instance)
          object_properties_hash = {}
          object_names_list.map do |object_name|
            object_properties_hash[object_name] = property_info(broker, element, iib_instance, object_name)
          end

          object_properties_hash
        end

        def property_info(broker, element, iib_instance, object_name)
          data = property_string(broker, element, iib_instance, object_name)
          Puppet.debug data
          return nil if data.empty?

          regexp_string = data.scan(Regexp.new("(?:#{object_name})=(.*)"))
          return nil if regexp_string.empty?

          regexp_string.flatten.first.strip.gsub!(/^\'|\'?$/, '')
        end

        def property_string(broker, element, iib_instance, object_name)
          mqsireportproperties("#{broker} -c SecurityProfiles -o #{element} -n #{object_name}", instance: iib_instance)
        end
      end
    end
  end
end
