#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
require 'puppet_x/enterprisemodules/iib/ace_check'
require 'puppet_x/enterprisemodules/iib/ace_helpers'
require 'puppet_x/enterprisemodules/iib/command'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/property_mapper'
require 'puppet_x/enterprisemodules/iib/settings'
require 'puppet_x/enterprisemodules/iib/node_component'

class Puppet_X::EnterpriseModules::Iib::SecurityProfileProperty < Puppet::Property
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::AceCheck
  include Puppet_X::EnterpriseModules::Iib::AceHelpers
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings
  extend  Puppet_X::EnterpriseModules::Iib::NodeComponent
  extend  Puppet_X::EnterpriseModules::Iib::PropertyMapper

  def self.quote_values(value = nil)
    value ? @quote_values = value : (@quote_values || false)
  end

  def self.maps_to(attribute_name)
    self.attribute_name(attribute_name)
  end

  def self.attribute_name(attribute_name = nil)
    @attribute_name = attribute_name || @attribute_name
  end

  def self.translate_to_resource(raw_resource, resource)
    raw_resource.merge(resource)

    if ace_used?(raw_resource[:instance])
      return yaml_value(raw_resource, 'iib_security_profile')
    end

    value = raw_resource[:output][attribute_name]
    return nil if value.nil?

    value.empty? ? nil : value
  end

  def self.assign_value(node, security_profile, attribute_name, value, instance)
    mqsichangeproperties("#{node} -c SecurityProfiles -o " \
                         "#{security_profile} -n #{attribute_name} -v #{quoted_value(value)}",
                         { :instance => instance })
  end

  def new_attribute_value(resource, attribute_name, value)
    self.class.assign_value(resource[:broker], resource[:security_profile], attribute_name, value, resource[:instance])
  end

  after_create do
    new_attribute_value(resource, self.class.attribute_name, value)
  end

  on_modify do
    new_attribute_value(resource, self.class.attribute_name, value)
  end

  private

  def self.quoted_value(value)
    return value unless @quote_values
    # Values with comma's need some strange escaping
    if value.include?(',')
      "\\\\\\\"#{value}\\\\\\\""
    else
      "'#{value}'"
    end
  end
end
