#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Style/ClassAndModuleCamelCase
require 'puppet_x/enterprisemodules/iib/ace_check'
require 'puppet_x/enterprisemodules/iib/ace_helpers'
require 'puppet_x/enterprisemodules/iib/command'
require 'puppet_x/enterprisemodules/iib/commands'
require 'puppet_x/enterprisemodules/iib/property_mapper'
require 'puppet_x/enterprisemodules/iib/settings'

class Puppet_X::EnterpriseModules::Iib::ServerArrayProperty < Puppet::Property
  include EasyType
  include Puppet_X::EnterpriseModules::Iib::AceCheck
  include Puppet_X::EnterpriseModules::Iib::AceHelpers
  include Puppet_X::EnterpriseModules::Iib::Commands
  include Puppet_X::EnterpriseModules::Iib::Settings
  extend  Puppet_X::EnterpriseModules::Iib::PropertyMapper

  def self.translate_to_resource(raw_resource, resource)
    raw_resource.merge(resource)

    if ace_used?(raw_resource[:instance])
      return yaml_value(raw_resource, 'iib_server')
    end

    value = attrbute_value(raw_resource[:output], object_name, attribute_name).split(/,/)
    return nil if value.nil?

    value.empty? ? nil : value
  end

  def self.attribute_value(resource, object_name, attribute_name, value)
    list_value = value.length > 1 ? '\\\\\"' + value.join(',') + '\\\\\"' : value[0]

    mqsichangeproperties("#{resource[:broker]} -o #{object_name} -n " \
                         "#{attribute_name} -e #{resource[:server]} -v #{list_value}",
                         { :instance => resource[:instance] })
  end

  def new_attribute_value(resource, object_name, attribute_name, value)
    self.class.attribute_value(resource, object_name, attribute_name, value)
  end

  on_apply do
    if ace_used?(resource[:instance])
      self.class.write_to_yaml(resource, value, 'iib_server')
    else
      new_attribute_value(resource, self.class.object_name, self.class.attribute_name, value)
    end
  end
end
